@@ -39,8 +39,8 @@ class ThetaService(object):
 
     def get_block_range_for_date(self, date):
         start_datetime = datetime.combine(date, datetime.min.time().replace(tzinfo=timezone.utc))
-        end_datetime = datetime.combine(date, datetime.min.time().replace(tzinfo=timezone.utc) + 1)
-        #end_datetime = datetime.combine(date, datetime.max.time().replace(tzinfo=timezone.utc))
+        # end_datetime = datetime.combine(date, datetime.min.time().replace(tzinfo=timezone.utc))
+        end_datetime = datetime.combine(date, datetime.max.time().replace(tzinfo=timezone.utc))
         return self.get_block_range_for_timestamps(start_datetime.timestamp(), end_datetime.timestamp())
 
     def get_block_range_for_timestamps(self, start_timestamp, end_timestamp):
@@ -49,23 +49,23 @@ class ThetaService(object):
         if start_timestamp > end_timestamp:
             raise ValueError('start_timestamp must be greater or equal to end_timestamp')
 
-        try:
-            start_block_bounds = self._graph_operations.get_bounds_for_y_coordinate(start_timestamp)
-        except OutOfBoundsError:
-            start_block_bounds = (0, 0)
+#        try:
+#           start_block_bounds = self._graph_operations.get_bounds_for_y_coordinate(start_timestamp)
+#        except OutOfBoundsError:
+#            start_block_bounds = (0, 0)
 
-        try:
-            end_block_bounds = self._graph_operations.get_bounds_for_y_coordinate(end_timestamp)
-        except OutOfBoundsError as e:
-            raise OutOfBoundsError('The existing blocks do not completely cover the given time range') from e
+        # try:
+        #     end_block_bounds = self._graph_operations.get_bounds_for_y_coordinate(end_timestamp)
+        # except OutOfBoundsError as e:
+            #raise OutOfBoundsError('The existing blocks do not completely cover the given time range') from e
 
-        if start_block_bounds == end_block_bounds and start_block_bounds[0] != start_block_bounds[1]:
-            self.logger.info("end_block_bounds[0] %d,  end_block_bounds[1] : %d, start_block_bounds[0] %d, start_block_bounds[1] %d \n", 
-                end_block_bounds[0], end_block_bounds[1], start_block_bounds[0], start_block_bounds[0])
-            raise ValueError('The given timestamp range does not cover any blocks')
+        # if start_block_bounds == end_block_bounds and start_block_bounds[0] != start_block_bounds[1]:
+        #     self.logger.info("end_block_bounds[0] %d,  end_block_bounds[1] : %d, start_block_bounds[0] %d, start_block_bounds[1] %d \n", 
+        #         end_block_bounds[0], end_block_bounds[1], start_block_bounds[0], start_block_bounds[1])
+            # raise ValueError('The given timestamp range does not cover any blocks')
 
-        start_block = start_block_bounds[1]
-        end_block = end_block_bounds[0]
+        start_block = 1#start_block_bounds[1]
+        end_block = 6807304#end_block_bounds[0]
 
         # The genesis block has timestamp 0 but we include it with the 1st block.
         if start_block == 1:
